# jaggimage-viewer

I was so used to my 25+ years old version of ACDSee to quickly see my files, i just made my own image viewer with Python and Qt.

## Usage

- You can run it without argument in any directory containing pictures, it will show the first of files with any recognized extension, and next/prev will show others files in current directory
- You can run it with one file name as argument to display it (or associate jaggimage-viewer with images files), next/prev will also show others files of the same directory
- You can run it with several files as argument, the first one will be displayed, next/prev will show others images you listed

## Shortcuts

Most keyboard shortcuts are shown in the contextual menu (right click), but some functions have several. I tried to keep the sames shortcuts than ACDSee.

| Functionality | Shortcut(s) | |-------------------------------------------------------------------|-------------------------------------------------------| | Toggle full-screen mode | `F`, `F11`, Double-click | | Toggle status bar | `B` | | Next image | `Space`, `Page Down`, Mouse wheel | | Previous image | `Backspace`, `Page Up`, Mouse wheel | | Zoom in | `+`, `Ctrl` (or `Shift`)+Mouse Wheel | | Zoom out | `-`, `Ctrl` (or `Shift`)+Mouse Wheel | | Zoom 1:1 ("pixel perfect") | `/` | | Toggle zoom best-fit / full width or height | `*` | | Zoom lock (zoom level not changing when displaying another image) | `Ctrl`+`/` | | Panning image (if not zoomed best fit) | Arrows keys (with `Ctrl`is faster, `Shift` is slower) | | Edit file description | `Ctrl+D` | | Rename file (and .txt description file, if present) | `F2` | | Reload file and relist directory | `F5` | | Show contextual menu | `F10` | | Open a specific file (in same or different directory) | `Ctrl`+`O` | | Copy current image to clipboard | `Ctrl`+`C` | | Open the image with an external editor (gimp by default) | `Ctrl`+`E` | | Quit the program | `Escape`, `Ctrl`+`W` |

## Installation

### From PyPI

This assumes you have either `Python` and `pip`, or `uv` installed.

With `pip`:

`shell pip install jaggimage-viewer`

With `uv`:

`shell uv tool install jaggimage-viewer`

### From sources

1. Have `uv` installed: https://docs.astral.sh/uv/#installation

2. Clone the repository:

   `shell git clone https://github.com/clxjaguar/jaggimage-viewer.git`

3. Run the installation:

   `shell cd jaggimage-viewer uv build uv tool install .`